@@ -1,11 +1,14 @@
+import sys
+
+from mmif import __specver__
+
+from clams import source
 from clams.app import *
 from clams.app import __all__ as app_all
 from clams.appmetadata import AppMetadata
 from clams.restify import Restifier
-from clams import source
 from clams.source import PipelineSource
 from clams.ver import __version__
-from mmif import __specver__
 
 __all__ = [AppMetadata, 'Restifier', 'PipelineSource'] + app_all
 version_template = "{} (based on MMIF spec: {})"
@@ -19,14 +22,16 @@ def prep_argparser():
         action='version',
         version=version_template.format(__version__, __specver__)
     )
-    subparsers = parser.add_subparsers()
-    subparsers._name_parser_map['source'] = source.prep_argparser()
+    subparsers = parser.add_subparsers(dest='subcmd')
+    subparsers.add_parser('source', parents=[source.prep_argparser()], add_help=False)
     return parser
 
 
 def cli():
     parser = prep_argparser()
+    if len(sys.argv) == 1:
+        parser.print_help(sys.stderr)
+        sys.exit(1)
     args = parser.parse_args()
-
-    if args.documents:
-        print(source.generate_source_mmif(**vars(args)))
+    if args.subcmd == 'source':
+        source.main(args)
